% Candidate filters:
% - Median filter.
% - Dataset trimming.
% - Tossing out distance neighbors
% - Too expensive options like RANSAC or curve fitting

% Because we know that the curves are roughly sine-like, we have a good
% idea of what constitutes a "distant" neighbor. It is a function of
% samples per second (RPM):

rpm = 3000;
per = 60/rpm;
spc = 8000/(rpm/60);
per_diff = sin(pi/2 + (2*pi/sps)) - sin(pi/2);

% So apparently, we expect less than 1% different from sample to sample,
% even at high RPM. In a perfect world.
% 1% difference at full scale is 4 ADC levels. Wow.
% So, it seems pretty conservative to say that all samples should be within
% 40 ADC levels of whatever was read last. Let's try that.

% Simulate what this type of thing would look like:
t = 0:(1/8000):per;
wave = t;
peakt = 0;
peaka = 0;
for i = 1:length(t)
   if (rand > .2)
       wave(i) = -sin(t(i) * (2*pi/per));
   else
       wave(i) = -sin(t(i) * (2*pi/per)) + 2*(rand-.5);
   end
   if wave(i) > peaka(end) && wave(i) - peaka(end) < .1
       peakt(end+1) = t(i); peakt(end+1) = t(i);
       peaka(end+1) = peaka(end); peaka(end+1) = wave(i); 
   end
end
peakt(end+1) = t(i); peaka(end+1) = peaka(end);
plot(t, wave); hold on; plot(peakt, peaka);